@@ -680,6 +680,97 @@ describe('clone()', () => {
         expect(b.get(nestedObj)).to.equal(a.get(nestedObj));
     });
 
+    it('clones an URL', () => {
+
+        const a = new URL('https://hapi.dev/');
+        const b = Hoek.clone(a);
+
+        expect(b.href).to.equal(a.href);
+        expect(b).to.not.shallow.equal(a);
+    });
+
+    it('clones Error', () => {
+
+        class CustomError extends Error {
+            name = 'CustomError';
+        }
+
+        const a = new CustomError('bad');
+        a.test = Symbol('test');
+
+        const b = Hoek.clone(a);
+
+        expect(b).to.equal(a);
+        expect(b).to.not.shallow.equal(a);
+        expect(b).to.be.instanceOf(CustomError);
+        expect(b.stack).to.equal(a.stack);                 // Explicitly validate the .stack getters
+    });
+
+    it('clones Error with cause', { skip: process.version.startsWith('v14') }, () => {
+
+        const a = new TypeError('bad', { cause: new Error('embedded') });
+        const b = Hoek.clone(a);
+
+        expect(b).to.equal(a);
+        expect(b).to.not.shallow.equal(a);
+        expect(b).to.be.instanceOf(TypeError);
+        expect(b.stack).to.equal(a.stack);                 // Explicitly validate the .stack getters
+        expect(b.cause.stack).to.equal(a.cause.stack);     // Explicitly validate the .stack getters
+    });
+
+    it('clones Error with error message', () => {
+
+        const a = new Error();
+        a.message = new Error('message');
+
+        const b = Hoek.clone(a);
+
+        //expect(b).to.equal(a);                           // deepEqual() always compares message using ===
+        expect(b.message).to.equal(a.message);
+        expect(b.message).to.not.shallow.equal(a.message);
+        expect(b.stack).to.equal(a.stack);
+    });
+
+    it('clones Error with function property', () => {
+
+        const a = new Error('hello');
+        a.fun = new Function();
+
+        const b = Hoek.clone(a);
+
+        expect(b).to.equal(a);
+        expect(b.stack).to.equal(a.stack);
+    });
+
+    it('clones legacy extended Error with function property', () => {
+
+        const CustomError = function () {
+
+            Error.call(this);
+        };
+
+        Object.setPrototypeOf(CustomError.prototype, Error.prototype);
+
+        const a = new CustomError('hello');
+        a.fun = new Function();
+
+        const b = Hoek.clone(a);
+
+        expect(b).to.equal(a);
+        expect(b.stack).to.equal(a.stack);
+    });
+
+    it('cloned Error handles late stack update', () => {
+
+        const a = new Error('bad');
+        const b = Hoek.clone(a);
+
+        a.stack = 'late update';
+
+        expect(b).to.equal(a);
+        expect(b.stack).to.not.equal(a.stack);
+    });
+
     it('ignores symbols', () => {
 
         const sym = Symbol();
@@ -824,4 +915,32 @@ describe('clone()', () => {
         const b = Hoek.clone(a);
         expect(b.x).to.not.exist();
     });
+
+    it('handles structuredClone not returning proper Error instances', { skip: typeof structuredClone !== 'function' }, () => {
+
+        // This can happen when running in a VM
+
+        const error = new Error('blam');
+
+        const origStructuredClone = structuredClone;
+        try {
+            structuredClone = function (obj) {
+
+                const clone = origStructuredClone.call(this, obj);
+                if (obj === error) {
+                    Object.setPrototypeOf(clone, Object);
+                }
+
+                return clone;
+            };
+
+            var cloned = Hoek.clone(error);
+        }
+        finally {
+            structuredClone = origStructuredClone;
+        }
+
+        expect(cloned).to.be.instanceOf(Error);
+        expect(cloned).to.equal(error);
+    });
 });
