@@ -1154,6 +1154,15 @@ describe('deepEqual()', () => {
         expect(Hoek.deepEqual(a, new Promise(() => { }))).to.be.false();
     });
 
+    it('compares urls', () => {
+
+        const a = new URL('https://hapi.dev/');
+
+        expect(Hoek.deepEqual(a, a)).to.be.true();
+        expect(Hoek.deepEqual(a, new URL('https://hapi.dev/?new'))).to.be.false();
+        expect(Hoek.deepEqual(a, {}, { prototype: false })).to.be.false();
+    });
+
     it('compares buffers', () => {
 
         expect(Hoek.deepEqual(Buffer.from([1, 2, 3]), Buffer.from([1, 2, 3]))).to.be.true();
@@ -2102,7 +2111,7 @@ describe('assert()', () => {
         expect(() => {
 
             Hoek.assert(false, 'my error message');
-        }).to.throw('my error message');
+        }).to.throw(Hoek.AssertError, 'my error message');
     });
 
     it('throws an Error when using assert in a test with no message', () => {
@@ -2110,7 +2119,7 @@ describe('assert()', () => {
         expect(() => {
 
             Hoek.assert(false);
-        }).to.throw('Unknown error');
+        }).to.throw(Hoek.AssertError, 'Unknown error');
     });
 
     it('throws an Error when using assert in a test with multipart message', () => {
@@ -2118,7 +2127,7 @@ describe('assert()', () => {
         expect(() => {
 
             Hoek.assert(false, 'This', 'is', 'my message');
-        }).to.throw('This is my message');
+        }).to.throw(Hoek.AssertError, 'This is my message');
     });
 
     it('throws an Error when using assert in a test with multipart message (empty)', () => {
@@ -2126,7 +2135,7 @@ describe('assert()', () => {
         expect(() => {
 
             Hoek.assert(false, 'This', 'is', '', 'my message');
-        }).to.throw('This is my message');
+        }).to.throw(Hoek.AssertError, 'This is my message');
     });
 
     it('throws an Error when using assert in a test with object message', () => {
@@ -2134,7 +2143,7 @@ describe('assert()', () => {
         expect(() => {
 
             Hoek.assert(false, 'This', 'is', { spinal: 'tap' });
-        }).to.throw('This is {"spinal":"tap"}');
+        }).to.throw(Hoek.AssertError, 'This is {"spinal":"tap"}');
     });
 
     it('throws an Error when using assert in a test with multipart string and error messages', () => {
@@ -2142,13 +2151,13 @@ describe('assert()', () => {
         expect(() => {
 
             Hoek.assert(false, new Error('This'), 'is', 'spinal', new Error('tap'));
-        }).to.throw('This is spinal tap');
+        }).to.throw(Hoek.AssertError, 'This is spinal tap');
     });
 
     it('throws an Error when using assert in a test with error object message', () => {
 
-        const err = new Error('This is spinal tap');
-        const got = expect(() => Hoek.assert(false, err)).to.throw('This is spinal tap');
+        const err = new TypeError('This is spinal tap');
+        const got = expect(() => Hoek.assert(false, err)).to.throw(TypeError, 'This is spinal tap');
         expect(got).to.shallow.equal(err);
     });
 
@@ -2172,6 +2181,34 @@ describe('assert()', () => {
     });
 });
 
+describe('AssertError', () => {
+
+    it('takes an optional message', () => {
+
+        expect(new Hoek.AssertError().message).to.equal('Unknown error');
+        expect(new Hoek.AssertError(null).message).to.equal('Unknown error');
+        expect(new Hoek.AssertError('msg').message).to.equal('msg');
+    });
+
+    it('has AssertError name property', () => {
+
+        expect(new Hoek.AssertError().name).to.equal('AssertError');
+        expect(new Hoek.AssertError('msg').name).to.equal('AssertError');
+    });
+
+    it('uses ctor argument to hide stack', { skip: typeof Error.captureStackTrace !== 'function' }, () => {
+
+        const parentFn = () => {
+
+            throw new Hoek.AssertError('msg', parentFn);
+        };
+
+        const err = expect(parentFn).to.throw(Hoek.AssertError);
+
+        expect(err.stack).to.not.contain('parentFn');
+    });
+});
+
 describe('Bench', () => {
 
     it('returns time elapsed', async () => {
